@@ -2,7 +2,7 @@
 
 
 __title__ = 'tipi'
-__version__ = '0.0.1dev'
+__version__ = '0.0.2'
 __author__ = 'Honza Javorek'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2013 Honza Javorek'
@@ -19,4 +19,4 @@ def tipi(html, lang='en'):
     """Performs language-sensitive typographic replacements on given HTML
     string. No replacements take place in case of unknown language.
     """
-    return replace(html, patterns=langs[lang])
+    return replace(html, replacements=langs[lang])
